@@ -30,7 +30,7 @@ from pydantic import BaseModel, Field, ValidationError, root_validator, validato
 from .auth import AbstractAuth
 from .const import ITEMS
 from .exceptions import ApiException
-from .model import EVENT_FIELDS, Calendar, DateOrDatetime, Event, EventStatusEnum
+from .model import EVENT_FIELDS, Calendar, Event, EventStatusEnum
 from .store import CalendarStore
 from .timeline import Timeline, calendar_timeline
 
@@ -53,7 +53,7 @@ __all__ = [
 _LOGGER = logging.getLogger(__name__)
 
 
-EVENT_PAGE_SIZE = 100
+EVENT_PAGE_SIZE = 1000
 # pylint: disable=line-too-long
 EVENT_API_FIELDS = f"kind,nextPageToken,nextSyncToken,items({EVENT_FIELDS})"
 
@@ -449,18 +449,18 @@ class CalendarEventStoreService:
             return LocalListEventsResponse(
                 events=list(
                     timeline.overlapping(
-                        DateOrDatetime(date_time=request.start_time),
-                        DateOrDatetime(date_time=request.end_time),
+                        request.start_time,
+                        request.end_time,
                     )
                 )
             )
         return LocalListEventsResponse(
-            events=list(
-                timeline.active_after(DateOrDatetime(date_time=request.start_time))
-            )
+            events=list(timeline.active_after(request.start_time))
         )
 
-    async def async_get_timeline(self) -> Timeline:
+    async def async_get_timeline(
+        self, tzinfo: datetime.tzinfo | None = None
+    ) -> Timeline:
         """Get the timeline of events."""
         store_data = await self._store.async_load() or {}
         store_data.setdefault(ITEMS, {})
@@ -474,4 +474,4 @@ class CalendarEventStoreService:
                 continue
             events.append(event)
 
-        return calendar_timeline(events)
+        return calendar_timeline(events, tzinfo if tzinfo else datetime.timezone.utc)
